@@ -1,4 +1,4 @@
-matchit2optimal <- function(treat, X, data, distance, discarded,
+matchit2optimal <- function(treat, X, data, distance, discarded, is.full.mahalanobis, 
                             ratio = 1, verbose=FALSE, ...) {
 
   if (!("optmatch" %in% .packages(all = TRUE)))
